==> jc-1.4.0.tar.gz: java/security/KeyPairGeneratorSpi.h <==
// public abstract class java.security.KeyPairGeneratorSpi

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 688f793da35179d1 java_security_KeyPairGeneratorSpi

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_KeyPairGeneratorSpi_H_
#define _JC_java_security_KeyPairGeneratorSpi_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_security_KeyPair$object;
struct _jc_java_security_SecureRandom$object;
struct _jc_java_security_spec_AlgorithmParameterSpec$object;

// Typedefs
typedef struct _jc_java_security_KeyPairGeneratorSpi$sub_refs	_jc_java_security_KeyPairGeneratorSpi$sub_refs;
typedef struct _jc_java_security_KeyPairGeneratorSpi$sub_nonrefs	_jc_java_security_KeyPairGeneratorSpi$sub_nonrefs;
typedef struct _jc_java_security_KeyPairGeneratorSpi$refs	_jc_java_security_KeyPairGeneratorSpi$refs;
typedef struct _jc_java_security_KeyPairGeneratorSpi$nonrefs	_jc_java_security_KeyPairGeneratorSpi$nonrefs;
typedef struct _jc_java_security_KeyPairGeneratorSpi$object	_jc_java_security_KeyPairGeneratorSpi$object;

typedef const struct _jc_java_security_KeyPairGeneratorSpi$vmethods	_jc_java_security_KeyPairGeneratorSpi$vmethods;
typedef const struct _jc_java_security_KeyPairGeneratorSpi$vtable	_jc_java_security_KeyPairGeneratorSpi$vtable;
typedef const struct _jc_java_security_KeyPairGeneratorSpi$vtype	_jc_java_security_KeyPairGeneratorSpi$vtype;

// Constructors
extern void _jc_java_security_KeyPairGeneratorSpi$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_KeyPairGeneratorSpi$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_security_KeyPairGeneratorSpi$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_java_security_KeyPairGeneratorSpi$object *);
extern struct _jc_java_security_KeyPair$object *_jc_java_security_KeyPairGeneratorSpi$method$generateKeyPair$e0a9411286c772d9(_jc_env *, struct _jc_java_security_KeyPairGeneratorSpi$object *);
extern void _jc_java_security_KeyPairGeneratorSpi$method$initialize$8377579c986315b7(_jc_env *, struct _jc_java_security_KeyPairGeneratorSpi$object *, jint, struct _jc_java_security_SecureRandom$object *);
extern void _jc_java_security_KeyPairGeneratorSpi$method$initialize$a73c0ba67824ad04(_jc_env *, struct _jc_java_security_KeyPairGeneratorSpi$object *, struct _jc_object *, struct _jc_java_security_SecureRandom$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_KeyPairGeneratorSpi$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_java_security_KeyPairGeneratorSpi$method_info$generateKeyPair$e0a9411286c772d9;
extern _jc_method _jc_java_security_KeyPairGeneratorSpi$method_info$initialize$8377579c986315b7;
extern _jc_method _jc_java_security_KeyPairGeneratorSpi$method_info$initialize$a73c0ba67824ad04;

// Virtual methods structure
struct _jc_java_security_KeyPairGeneratorSpi$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_java_security_KeyPairGeneratorSpi$object *);
	struct _jc_java_security_KeyPair$object	*(*generateKeyPair$e0a9411286c772d9)(_jc_env *, struct _jc_java_security_KeyPairGeneratorSpi$object *);
	void	(*initialize$8377579c986315b7)(_jc_env *, struct _jc_java_security_KeyPairGeneratorSpi$object *, jint, struct _jc_java_security_SecureRandom$object *);
	void	(*initialize$a73c0ba67824ad04)(_jc_env *, struct _jc_java_security_KeyPairGeneratorSpi$object *, struct _jc_object *, struct _jc_java_security_SecureRandom$object *);
};

// Vtable
struct _jc_java_security_KeyPairGeneratorSpi$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_KeyPairGeneratorSpi$vmethods	java_security_KeyPairGeneratorSpi;
};

// Vtype
struct _jc_java_security_KeyPairGeneratorSpi$vtype {
	_jc_type			type;
	_jc_java_security_KeyPairGeneratorSpi$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_KeyPairGeneratorSpi$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_KeyPairGeneratorSpi$refs {
    _jc_java_security_KeyPairGeneratorSpi$sub_refs	java_security_KeyPairGeneratorSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_KeyPairGeneratorSpi$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_KeyPairGeneratorSpi$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_KeyPairGeneratorSpi$sub_nonrefs	java_security_KeyPairGeneratorSpi;
};

// Object instance structure
struct _jc_java_security_KeyPairGeneratorSpi$object {
	_jc_java_security_KeyPairGeneratorSpi$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_KeyPairGeneratorSpi$vtype	*vtype;
	_jc_java_security_KeyPairGeneratorSpi$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_KeyPairGeneratorSpi$vtype _jc_java_security_KeyPairGeneratorSpi$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_KeyPairGeneratorSpi, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_KeyPairGeneratorSpi$class_object;

#endif	/* _JC_java_security_KeyPairGeneratorSpi_H_ */

==> jc-1.4.6.tar.gz: java/security/KeyPairGeneratorSpi.h <==
// public abstract class java.security.KeyPairGeneratorSpi

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 688f793da35179d1 java_security_KeyPairGeneratorSpi

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_KeyPairGeneratorSpi_H_
#define _JC_java_security_KeyPairGeneratorSpi_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_security_KeyPair$object;
struct _jc_java_security_SecureRandom$object;
struct _jc_java_security_spec_AlgorithmParameterSpec$object;

// Typedefs
typedef struct _jc_java_security_KeyPairGeneratorSpi$sub_refs	_jc_java_security_KeyPairGeneratorSpi$sub_refs;
typedef struct _jc_java_security_KeyPairGeneratorSpi$sub_nonrefs	_jc_java_security_KeyPairGeneratorSpi$sub_nonrefs;
typedef struct _jc_java_security_KeyPairGeneratorSpi$refs	_jc_java_security_KeyPairGeneratorSpi$refs;
typedef struct _jc_java_security_KeyPairGeneratorSpi$nonrefs	_jc_java_security_KeyPairGeneratorSpi$nonrefs;
typedef struct _jc_java_security_KeyPairGeneratorSpi$object	_jc_java_security_KeyPairGeneratorSpi$object;

typedef const struct _jc_java_security_KeyPairGeneratorSpi$vmethods	_jc_java_security_KeyPairGeneratorSpi$vmethods;
typedef const struct _jc_java_security_KeyPairGeneratorSpi$vtable	_jc_java_security_KeyPairGeneratorSpi$vtable;
typedef const struct _jc_java_security_KeyPairGeneratorSpi$vtype	_jc_java_security_KeyPairGeneratorSpi$vtype;

// Constructors
extern void _jc_java_security_KeyPairGeneratorSpi$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_KeyPairGeneratorSpi$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_security_KeyPairGeneratorSpi$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_java_security_KeyPairGeneratorSpi$object *) _JC_JCNI_ATTR;
extern struct _jc_java_security_KeyPair$object *_jc_java_security_KeyPairGeneratorSpi$method$generateKeyPair$e0a9411286c772d9(_jc_env *, struct _jc_java_security_KeyPairGeneratorSpi$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_KeyPairGeneratorSpi$method$initialize$8377579c986315b7(_jc_env *, struct _jc_java_security_KeyPairGeneratorSpi$object *, jint, struct _jc_java_security_SecureRandom$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_KeyPairGeneratorSpi$method$initialize$a73c0ba67824ad04(_jc_env *, struct _jc_java_security_KeyPairGeneratorSpi$object *, struct _jc_object *, struct _jc_java_security_SecureRandom$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_KeyPairGeneratorSpi$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_java_security_KeyPairGeneratorSpi$method_info$generateKeyPair$e0a9411286c772d9;
extern _jc_method _jc_java_security_KeyPairGeneratorSpi$method_info$initialize$8377579c986315b7;
extern _jc_method _jc_java_security_KeyPairGeneratorSpi$method_info$initialize$a73c0ba67824ad04;

// Virtual methods structure
struct _jc_java_security_KeyPairGeneratorSpi$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_java_security_KeyPairGeneratorSpi$object *) _JC_JCNI_ATTR;
	struct _jc_java_security_KeyPair$object	*(*generateKeyPair$e0a9411286c772d9)(_jc_env *, struct _jc_java_security_KeyPairGeneratorSpi$object *) _JC_JCNI_ATTR;
	void	(*initialize$8377579c986315b7)(_jc_env *, struct _jc_java_security_KeyPairGeneratorSpi$object *, jint, struct _jc_java_security_SecureRandom$object *) _JC_JCNI_ATTR;
	void	(*initialize$a73c0ba67824ad04)(_jc_env *, struct _jc_java_security_KeyPairGeneratorSpi$object *, struct _jc_object *, struct _jc_java_security_SecureRandom$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_KeyPairGeneratorSpi$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_KeyPairGeneratorSpi$vmethods	java_security_KeyPairGeneratorSpi;
};

// Vtype
struct _jc_java_security_KeyPairGeneratorSpi$vtype {
	_jc_type			type;
	_jc_java_security_KeyPairGeneratorSpi$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_KeyPairGeneratorSpi$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_KeyPairGeneratorSpi$refs {
    _jc_java_security_KeyPairGeneratorSpi$sub_refs	java_security_KeyPairGeneratorSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_KeyPairGeneratorSpi$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_KeyPairGeneratorSpi$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_KeyPairGeneratorSpi$sub_nonrefs	java_security_KeyPairGeneratorSpi;
};

// Object instance structure
struct _jc_java_security_KeyPairGeneratorSpi$object {
	_jc_java_security_KeyPairGeneratorSpi$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_KeyPairGeneratorSpi$vtype	*vtype;
	_jc_java_security_KeyPairGeneratorSpi$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_KeyPairGeneratorSpi$vtype _jc_java_security_KeyPairGeneratorSpi$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_KeyPairGeneratorSpi, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_KeyPairGeneratorSpi$class_object;

#endif	/* _JC_java_security_KeyPairGeneratorSpi_H_ */
